@@ -30,8 +30,8 @@ class Command(BaseCommand):
                 user_prefs.NotificationEnable.append(ntype)
 
             response = EbaySuds.SetNotificationPreferences(
-                ApplicationDeliveryPreferences=app_prefs
-                UserDeliveryPreferenceArray=user_prefs
+                ApplicationDeliveryPreferences=app_prefs,
+                UserDeliveryPreferenceArray=user_prefs,
             )
             print response.Ack
         else:
